/***************************************************************************
 *
 * common.h : Common functions shared between modules
 *
 * Copyright (C) 2005 Richard Hughes, <richard@hughsie.com>
 *
 * Licensed under the GNU GPL v2.  See COPYING.
 *
 **************************************************************************/

#ifndef _COMMON_H
#define _COMMON_H
#define MAX_ICONS		7
#include "eggtrayicon.h"
#include <gnome.h>

typedef enum {
	ACTION_POWER_STATE_CHANGE,
	ACTION_NOTHING,
	ACTION_WARNING,
	ACTION_SUSPEND,
	ACTION_HIBERNATE,
	ACTION_SHUTDOWN,

	ACTION_BUTTON_PLACEHOLDER,

	ACTION_BUTTON_SLEEP,
	ACTION_BUTTON_POWER,
	ACTION_BUTTON_LID,
	ACTION_UPS_LOW,
	ACTION_UPS_CHARGE,
	ACTION_UPS_DISCHARGE,
	ACTION_BATTERY_LOW,
	ACTION_BATTERY_CHARGE,
	ACTION_BATTERY_DISCHARGE,
	ACTION_NOW_BATTERYPOWERED,
	ACTION_NOW_MAINSPOWERED,
	ACTION_NOW_HASBATTERIES,
	ACTION_NOW_NOBATTERIES
} ActionType;

typedef enum {
	POWER_NONE,
	POWER_UNKNOWN,
	POWER_AC_ADAPTER,
	POWER_BATTERY,
	POWER_UPS,
	POWER_MOUSE,
	POWER_KEYBOARD,
	POWER_LCD
} PowerDevice;

typedef enum {
	BUTTON_POWER,
	BUTTON_SLEEP,
	BUTTON_LID,
	BUTTON_UNKNOWN
} ButtonDevice;

typedef enum {
	CHARGE_EMPTY, 		/* <10% */
	CHARGE_VLOW,  		/* 20-40% */
	CHARGE_LOW, 		/* 40-60% */
	CHARGE_HIGH,  		/* 60-80% */
	CHARGE_VHIGH, 		/* 80-100% */
	CHARGE_FULL  		/* 100% */
} PowerState;

typedef enum {
	REPORT_PERCENT,
	REPORT_MWH,
	REPORT_UNKNOWN
} ReportType;

typedef struct {
	gboolean hasDisplays;
	gboolean hasHardDrive;
	gboolean hasLCD;
	gboolean hasWireless;
	gboolean hasAcAdapter;
	gboolean hasButtons;
	gboolean hasBatteries;
	gboolean hasUPS;
} HasData;

typedef struct {
	int idleTime;
	gboolean onBatteryPower;
	gboolean onUPSPower;
} StateData;

typedef struct {
	gboolean hasIcon;
	int slot;
	char udi[128];
	int powerDevice;    
	int powerState;
	int reportType;
	char *technologyType;
	int rawMinutesRemaining;
	int rawDesign;
	int rawLastFull;
	int rawCharge;
	int rawRate;
	int isRechargeable;
	int percentageCharge;
	int minutesRemaining;
	gboolean isCharging;
} GenericObject;

void updateHasLogic (GenericObject *slotBase, gboolean coldplug);
void updateStateLogic (GenericObject *slotBase, gboolean coldplug);
void updateMinutesRemainingFromSlot (GenericObject *slotData);
void updatePercentageChargeFromSlot (GenericObject *slotData);
void getTooltipFromSlot (GenericObject *slotData, char *tooltip);
void updatePowerStateFromSlot (GenericObject *slotData);
void getIconFilenameFromSlot (GenericObject *slotData, char *filename);

#endif	/* _COMMON_H */
