/***************************************************************************
 *
 * icons.c : Middle layer library for managing icons
 *
 * Copyright (C) 2005 Richard Hughes, <richard@hughsie.com>
 * Taken in part from:
 * - notibat (C) 2004 Benjamin Kahn <xkahn@zoned.net>
 *
 * Licensed under the GNU GPL v2.  See COPYING.
 *
 **************************************************************************/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gdk/gdkx.h>
#include <gnome.h>
#include <glade/glade.h>
#include "eggtrayicon.h"
#include "common.h"
#include "gpm.h"

TrayData *
icon_create (MenuData *md, int number, const char *filename, const char *tooltip)
{
	GtkWidget *evbox;
	TrayData *td;
	char *path;

	/* create new tray object */
	td = g_new0 (TrayData, 1);
	md->td[number] = td;

	/* Event box */
	evbox = gtk_event_box_new ();
	md->td[number]->evbox = evbox;

	td->tray_icon = egg_tray_icon_new ("Battery Monitor");

	path = g_strconcat (GPM_DATA, filename, NULL);
	/*printf ("loading icon from : %s\n", path);*/
	td->image = gtk_image_new_from_file (path);
	g_free (path);

	td->tray_icon_tooltip = gtk_tooltips_new ();
	gtk_tooltips_set_tip (td->tray_icon_tooltip, GTK_WIDGET (td->tray_icon), tooltip, NULL);

	g_signal_connect (G_OBJECT (evbox), "button_press_event", G_CALLBACK (tray_icon_press), (gpointer) md);
	g_signal_connect (G_OBJECT (evbox), "button_release_event", G_CALLBACK (tray_icon_release), (gpointer) md);

	gtk_container_add (GTK_CONTAINER (evbox), td->image);
	gtk_container_add (GTK_CONTAINER (td->tray_icon), evbox);

	gtk_widget_show_all (GTK_WIDGET (td->tray_icon));
	/* g_signal_connect (G_OBJECT (td->tray_icon), "destroy-event", G_CALLBACK (tray_destroyed), (gpointer) md); */
	return td;
}

void
icon_modify_image (TrayData *td, const char* filename)
{
	gchar *fullpath;
	fullpath = g_strconcat (GPM_DATA, filename, NULL);
	gtk_image_set_from_file (GTK_IMAGE (td->image), fullpath);
/*	printf ("Changing image to: %s\n", fullpath);*/
	g_free (fullpath);
}

void
icon_modify_tooltip (TrayData *td, const char* tooltip)
{
	gtk_tooltips_set_tip (td->tray_icon_tooltip, GTK_WIDGET (td->tray_icon), tooltip, NULL);
}

void
icon_destroy (TrayData *td)
{
	if (td == NULL)
		return;
	gtk_widget_hide_all (GTK_WIDGET (td->tray_icon));
	g_free(td);
}

gboolean
tray_icon_release (GtkWidget *widget, GdkEventButton *event, MenuData *md)
{
	if (event->button == 3)
	{
		gtk_menu_popdown (GTK_MENU (md->popup_menu));
		return FALSE;
	}

	return TRUE;
}

gboolean
tray_icon_press (GtkWidget *widget, GdkEventButton *event, MenuData *md)
{
	if (event->button == 3)
	{
		gtk_menu_popup (GTK_MENU (md->popup_menu), NULL, NULL, NULL, NULL, event->button, event->time);
		return TRUE;
	}

	return FALSE;
}
