/***************************************************************************
 *
 * info.c : Show the global power properties (usefull in shell scripts)
 *
 * NOTE:
 *  This file currently works out the states using libhal, ultimatly
 *  it will query g-p-m via DBUS on the org.gnome.PowerManager interface
 *
 * Copyright (C) 2005 Richard Hughes, <richard@hughsie.com>
 * Taken in part from:
 * - lshal   (C) 2003 David Zeuthen, <david@fubar.dk>
 *
 * Licensed under the GNU GPL v2.  See COPYING.
 *
 **************************************************************************/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <glib.h>
#include <dbus/dbus-glib.h>

#include <libhal.h>
#include "common.h"

static LibHalContext *hal_ctx;
static HasData sd;

/** LibHal setup
 *
 *  @param  conn		D-BUS connection
 *  @return			Success value
 */
static int
libhal_setup (DBusConnection *conn)
{
	DBusError error;
	dbus_error_init (&error);	
	conn = dbus_bus_get (DBUS_BUS_SYSTEM, &error);
	if (conn == NULL) {
		fprintf (stderr, "error: dbus_bus_get: %s: %s\n", error.name, error.message);
		return FALSE;
	}
	if ((hal_ctx = libhal_ctx_new ()) == NULL) {
		fprintf (stderr, "error: libhal_ctx_new\n");
		return FALSE;
	}
	if (!libhal_ctx_set_dbus_connection (hal_ctx, conn)) {
		fprintf (stderr, "error: libhal_ctx_set_dbus_connection: %s: %s\n", error.name, error.message);
		return FALSE;
	}
	if (!libhal_ctx_init (hal_ctx, &error)) {
		fprintf (stderr, "error: libhal_ctx_init: %s: %s\n", error.name, error.message);
		return FALSE;
	}
	return TRUE;
}

/** LibHal cleanup
 *
 *  @param  conn		D-BUS connection
 */
static void
libhal_cleanup (DBusConnection *conn)
{
	DBusError error;
	dbus_error_init (&error);
	libhal_ctx_shutdown (hal_ctx, &error);
	libhal_ctx_free (hal_ctx);
	dbus_connection_disconnect (conn);
	dbus_connection_unref (conn);
}

/** Entry point
 *
 *  @param  argc		Number of arguments given to program
 *  @param  argv		Arguments given to program
 *  @return			Return code
 */
int
main (int argc, char *argv[])
{
	DBusConnection *conn;
	if (!libhal_setup (conn))
		exit (1);

	/* initialise devices at startup */
/*
	logic_recalculate (hal_ctx, &sd);
	logic_print (&sd);
*/

	libhal_cleanup (conn);
	return 0;
}
