/***************************************************************************
 *
 * object_table.c : Common table functions shared between modules
 *
 * NOTE: The table functions are FAST. Much quicker than a linked list implimentation.
 *
 * Copyright (C) 2005 Richard Hughes, <richard@hughsie.com>
 *
 * Licensed under the GNU GPL v2.  See COPYING.
 *
 **************************************************************************/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <glib.h>

#include "common.h"

/** Prints the objectData table with any parameters
 *
 *  @param  slotBase		The base address for slot data (only needed because we are looping)
 */
void
object_table_print(GenericObject *slotBase)
{
	int a;
	GenericObject *slotData;
	slotData = slotBase;
	printf ("Dumping UDI's\n");
	for (a=0; a<MAX_ICONS; a++) {
		if (slotData->powerDevice != POWER_NONE) {
			printf ("[%i] udi: %s\n", a, slotData->udi);
			printf ("     powerDevice: %i\n", slotData->powerDevice);
			printf ("     powerState:  %i\n", slotData->powerState);
			printf ("     reportType:  %i\n", slotData->reportType);
		}
		slotData++;
	}
}

/** Finds a device from the objectData table
 *
 *  @param  udi			HAL UDI
 *  @param  slotData		the GenericObject reference
 *  @param  slotBase		The base address for slot data (only needed because we are looping)
 *  @return			TRUE if we are found
 */
gboolean
object_table_find(const char *udi, GenericObject **slotData, GenericObject *slotBase)
{
	int a;
	/* Does already exist? Needed for buggy bioses that give two events */
	for (a=0; a<MAX_ICONS; a++) {
		if (slotBase->powerDevice != POWER_NONE && strcmp (slotBase->udi, udi) == 0) {
			*slotData = slotBase;
			return TRUE;
		}
		slotBase++;
	}
	return FALSE;
}

/** Adds a device to the objectData table *IF DOES NOT EXIST*
 *
 *  @param  udi			HAL UDI
 *  @param  slotData		the GenericObject reference
 *  @param  slotBase		The base address for slot data (only needed because we are looping)
 *  @return			TRUE if we added to the table
 */
gboolean
object_table_add(const char *udi, GenericObject **slotData, GenericObject *slotBase)
{
	int a;
	GenericObject *slotBaseTemp = slotBase;
	/* Does already exist? Needed for buggy bioses that give two events */
	for (a=0; a<MAX_ICONS; a++) {
		if (slotBase->powerDevice != POWER_NONE && strcmp (slotBase->udi, udi) == 0)
			return FALSE;
		slotBase++;
	}
	/* get old value */
	slotBase = slotBaseTemp;
	for (a=0; a<MAX_ICONS; a++) {
		if (slotBase->powerDevice == POWER_NONE) {
			*slotData = slotBase;
			slotBase->powerDevice = POWER_UNKNOWN;
			slotBase->slot = a;
			strcpy(slotBase->udi, udi);
			return TRUE;
		}
		slotBase++;
	}
	return FALSE;
}

/** Removes a device from the objectData table IF EXISTS
 *
 *  @param  udi			HAL UDI
 *  @param  slotData		the GenericObject reference
 *  @param  slotBase		The base address for slot data (only needed because we are looping)
 *  @return			TRUE if we removed from the table
 */
gboolean
object_table_remove(const char *udi, GenericObject **slotData, GenericObject *slotBase)
{
	int a;
	for (a=0; a<MAX_ICONS; a++) {
		if (slotBase->powerDevice != POWER_NONE && strcmp (slotBase->udi, udi)==0) {
			*slotData = slotBase;
			slotBase->powerDevice = POWER_UNKNOWN;
			return TRUE;
		}
		slotBase++;
	}
	return FALSE;
}
